#!/bin/sh
#   Copyright (c) 2013 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of dSS11 WebSetup
#
#   This file is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This file is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. /www/pages/cgi-bin/errlib.sh
. /www/pages/cgi-bin/jsonlib.sh

SERVICE_CFG="/etc/default/remoteaccess"
PAGEKITE_CFG="/etc/default/pagekite"

set_pagekite_service() {
    if [[ -d "/etc/runit/pagekite" ]] && [[ -x /usr/sbin/sv ]]; then
        if [[ "$1" == "on" ]]; then 
            rm -f /etc/runit/pagekite/down > /dev/null 2>&1
            sv restart pagekite > /dev/null 2>&1
            echo "NO_START=0" > $SERVICE_CFG
        elif [[ "$1" == "off" ]]; then
            touch /etc/runit/pagekite/down > /dev/null 2>&1
            sv down pagekite > /dev/null 2>&1
            echo "NO_START=1" > $SERVICE_CFG
        fi
    fi

    return $ERR_OK
}

# $1 name, $2 password
set_pagekite_config() {
cat > $PAGEKITE_CFG << EOL
NAME=$1
PROXYPW=$2
PROXYPORT=443
DOMAIN=.digitalstrom.net
DDNS=http://dnsup.digitalstrom.net/?hostname=%s&myip=%s&sign=%s
V4FRONTEND=fe.digitalstrom.net
V4PORT=443
DEBUG=0
NOSSL=0
EOL
}

echo "Content-Type: application/json"
echo ""

# "$FORM_access"

if [[ "$1" != "on" ]] && [[ "$1" != "off" ]] && [[ "$1" != "configure" ]]; then
    json_error $ERR_PARAM "Invalid remoteaccess parameter value!"
    exit 1
fi

if [[ "$1" != "configure" ]]; then
    set_pagekite_service "$1"
else
    if [[ -z "$2" ]] || [[ -z "$3" ]]; then
        json_error "$ERR_PARAM" "Missing password or link parameter!"
        exit 1
    fi
    set_pagekite_config "$2" "$3"
fi
RETCODE="$?"
if [[ "$RETCODE" -ne "$ERR_OK" ]]; then
    json_error "$ERR_SOFTWARE" "Pagekite service configuration failed!"
    exit 1
fi

json_ok

